<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@inodbox.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *    \file       advancedpos/cashcontrol_stat.php
 *    \ingroup    advancedpos
 *    \brief      Home page of advancedpos top menu
 */

// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
    $res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"] . "/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME'];
$tmp2 = realpath(__FILE__);
$i = strlen($tmp) - 1;
$j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
    $i--;
    $j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1)) . "/main.inc.php")) {
    $res = @include substr($tmp, 0, ($i + 1)) . "/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php")) {
    $res = @include dirname(substr($tmp, 0, ($i + 1))) . "/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
    $res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
    $res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
    $res = @include "../../../main.inc.php";
}
if (!$res) {
    die("Include of main fails");
}

require_once DOL_DOCUMENT_ROOT . '/core/class/html.formfile.class.php';

global $user, $langs;

// Load translation files required by the page
$langs->loadLangs(array("advancedpos@advancedpos"));

$action = GETPOST('action', 'aZ09');
$socid = GETPOST('socid', 'int');


// Security check
if (empty($conf->takepos->enabled)) accessforbidden('Module not enabled');
if ($user->socid > 0)    // Protection if external user
{
    accessforbidden();
}
if (isset($user->socid) && $user->socid > 0) {
    $action = '';
    $socid = $user->socid;
}

$max = 5;
$now = dol_now();


/*
 * Actions
 */
global $hookmanager, $db;
$action = GETPOST('action', 'aZ09') ? GETPOST('action', 'aZ09') : 'view'; // The action 'add', 'create', 'edit', 'update', 'view', ...
$show_files = GETPOST('show_files', 'int'); // Show files area generated by bulk actions ?
$confirm = GETPOST('confirm', 'alpha'); // Result of a confirmation
$cancel = GETPOST('cancel', 'alpha'); // We click on a Cancel button
$toselect = GETPOST('toselect', 'array'); // Array of ids of elements selected into a list
$contextpage = GETPOST('contextpage', 'aZ') ? GETPOST('contextpage', 'aZ') : 'equipmentlist'; // To manage different context of search
$backtopage = GETPOST('backtopage', 'alpha'); // Go back to a dedicated page
$optioncss = GETPOST('optioncss', 'aZ'); // Option for the css output (always '' except when 'print')
$limit = GETPOST('limit', 'int') ? GETPOST('limit', 'int') : $conf->liste_limit;
$sortfield = GETPOST('sortfield', 'alpha');
$sortorder = GETPOST('sortorder', 'alpha');
$page = GETPOST('page', 'int');
// If $page is not defined, or '' or -1 or if we click on clear filters or if we select empty mass action

$hookmanager->initHooks(array('cashcontrolDate_stat')); // Note that conf->hooks_modules contains array
// Default sort order (if not yet defined by previous GETPOST)
$search = array();


// Definition of fields for list

$parameters = array();
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');


$now = dol_now();
llxHeader("", $langs->trans("Stat_DatePos"));
print load_fiche_titre($langs->trans("Stat_DatePos"), '', 'advancedpos.png@advancedpos');

require_once DOL_DOCUMENT_ROOT . '/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/html.formcompany.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/modules/facture/modules_facture.php';
require_once DOL_DOCUMENT_ROOT . '/compta/bank/class/account.class.php';
require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT . '/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/discount.class.php';
require_once DOL_DOCUMENT_ROOT . '/compta/paiement/class/paiement.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/functions2.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/invoice.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/company.lib.php';

$object = new Facture($db);
$object_product = new Product($db);

$now = dol_now();
$error = 0;

// Initialize technical object to manage hooks of page. Note that conf->hooks_modules contains array of hook context
$hookmanager->initHooks(array('cashcontrolDate_statlist'));
$extrafields = new ExtraFields($db);


// fetch optionals attributes and labels
$extrafields->fetch_name_optionals_label($object->table_element);

$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) {
    setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
}
/*
 * Actions
 */

// TODO mettre en place les changement apporté à ticket Z
/*
 * View
 */
$search_date_start = dol_mktime(GETPOST('startdatestat_advtakeposhour', 'int'), GETPOST('startdatestat_advtakeposmin', 'int'), 0, GETPOST('startdatestat_advtakeposmonth', 'int'), GETPOST('startdatestat_advtakeposday', 'int'), GETPOST('startdatestat_advtakeposyear', 'int'));
$search_date_end = dol_mktime(GETPOST('enddatestat_advtakeposhour', 'int'), GETPOST('enddatestat_advtakeposmin', 'int'), 59, GETPOST('enddatestat_advtakeposmonth', 'int'), GETPOST('enddatestat_advtakeposday', 'int'), GETPOST('enddatestat_advtakeposyear', 'int'));
$search_date_end = empty($search_date_end) ? dol_now() : $search_date_end;
$form = new Form($db);
print '<form method="POST" action="' . $_SERVER["PHP_SELF"] . '">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="stat">';
print '<div style="display: flex;align-items: center;justify-content: center;">';
print '<div style="padding-right: 10em"><td>' . $langs->trans("startdatestat_takepos") . '</td>';
print '<td>';
print $form->selectDate($search_date_start, 'startdatestat_advtakepos', 1, 1, 1, 'formdatestat_takepos', 1, 0);
print '</td>';
print "</div>\n";
print '<tr><td>' . $langs->trans("enddatestat_takepos") . '</td>';
print '<td>';
print $form->selectDate($search_date_end, 'enddatestat_advtakepos', 1, 1, 1, 'formdatestat_takepos', 1, 0);
print '</td>';
print "</tr>\n";
print '</div>';
print '<div style="padding-top:10px;display: flex;align-items: center;justify-content: center;">';
print '<div class="center">';
print '<input type="submit" class="button" name="add" value="' . dol_escape_htmltag($langs->trans("GenerateStat")) . '">';
print '</div>';
print '</div>';
print '<form>';


if (!empty($action)) {
    if ($action == "stat" && !empty($search_date_start)) {
        $_GET['optioncss'] = "print";
        require_once DOL_DOCUMENT_ROOT . '/compta/cashcontrol/class/cashcontrol.class.php';
        require_once DOL_DOCUMENT_ROOT . '/compta/bank/class/account.class.php';
        require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
        require_once DOL_DOCUMENT_ROOT . '/compta/cashcontrol/class/cashcontrol.class.php';
        require_once DOL_DOCUMENT_ROOT . '/core/lib/date.lib.php';

        $langs->load("advancedpos@advancedpos");

        $langs->loadLangs(array("bills", "banks", "products"));

//$limit = GETPOST('limit')?GETPOST('limit', 'int'):$conf->liste_limit;
        $sortorder = 'ASC';
        $sortfield = 'b.datev,b.dateo,b.rowid';

        $arrayfields = array(
            'p.categ' => array('label' => $langs->trans("Rubriques")),
            'c.nbr' => array('label' => $langs->trans("categNbr")),
            'c.HT' => array('label' => $langs->trans("HT")),
            'c.tva' => array('label' => $langs->trans("TVA")),
            'c.ttc' => array('label' => $langs->trans("SellingPrice_TTC")),
        );
        // Security check
        $sql = "SELECT f.rowid as facid, f.ref, f.datef as do, pf.amount as amount, b.fk_account as bankid, cp.code";
        $sql .= " FROM " . MAIN_DB_PREFIX . "paiement_facture as pf, " . MAIN_DB_PREFIX . "facture as f, " . MAIN_DB_PREFIX . "paiement as p, " . MAIN_DB_PREFIX . "c_paiement as cp, " . MAIN_DB_PREFIX . "bank as b";
        $sql .= " WHERE pf.fk_facture = f.rowid AND p.rowid = pf.fk_paiement AND cp.id = p.fk_paiement AND p.fk_bank = b.rowid";
        $sql .= " AND f.paye = 1";
        $sql .= " AND p.entity = " . $conf->entity; // Never share entities for features related to accountancy
        $syear = GETPOST("startdatestat_advtakeposyear");
        $smonthear = GETPOST("startdatestat_advtakeposmonth");
        $sday = GETPOST("startdatestat_advtakeposday");
        $eday = empty(GETPOST("enddatestat_advtakeposday")) ? dol_print_date(dol_now(), "%d") : GETPOST("enddatestat_advtakeposday");
        $eyear = empty(GETPOST("enddatestat_advtakeposyear")) ? dol_print_date(dol_now(), "%Y") : GETPOST("enddatestat_advtakeposyear");
        $emonthear = empty(GETPOST("enddatestat_advtakeposmonth")) ? dol_print_date(dol_now(), "%m") : GETPOST("enddatestat_advtakeposmonth");

        if ($syear && !$smonthear) {
            $sql .= " AND f.datec BETWEEN '" . $db->idate(dol_get_first_day($syear, 1)) . "' AND '" . $db->idate(dol_get_last_day($eyear, 12)) . "'";
        } elseif ($syear && $smonthear && !$sday) {
            $sql .= " AND f.datec BETWEEN '" . $db->idate(dol_get_first_day($syear, $smonthear)) . "' AND '" . $db->idate(dol_get_last_day($eday, $emonthear)) . "'";
        } elseif ($syear && $smonthear && $sday) {
            $sql .= " AND f.datec BETWEEN '" . $db->idate($search_date_start) . "' AND '" . $db->idate($search_date_end) . "'";
        } else {
            dol_print_error('', 'Year not defined');
        }
        $resql = $db->query($sql);
        if ($resql) {
            $num = $db->num_rows($resql);
            $i = 0;
            print "<!-- title of cash fence -->\n";
            print '<center>';
            print '<h2>';
            if ($object->status != $object::STATUS_DRAFT) {
                print $langs->trans("CashControl_Z") . " - " . $object->id;
            } else {
                print $langs->trans("CashControl_Z") . " - " . $langs->trans("Draft");
            }
            print "<br />";
            print "<u>" . $langs->trans("RAPPORT_(RAZ)") . "</u>";
            print "</h2>";
            print $mysoc->name;
            $userauthor = $object->fk_user_valid;
            if (empty($userauthor)) {
                $userauthor = $object->fk_user_creat;
            }

            $uservalid = new User($db);
            if ($userauthor > 0) {
                $uservalid->fetch($userauthor);
                print '<br>' . $langs->trans("Author") . ': ' . $uservalid->getFullName($langs);
            }
            print '<br>' . $langs->trans("Period") . ': ';
            print '<br>';
            print '    Du : ' . dol_print_date($search_date_start, 'dayhour');
            print '<br>';
            print '    au: ' . dol_print_date($search_date_end, 'dayhour');
            print '</center>';

            require_once DOL_DOCUMENT_ROOT . '/categories/class/categorie.class.php';
            $invoicetmp = new Facture($db);
            $old_id = 0;
            $distint_ref = 0;
            $invoicetmp = new Facture($db);
            $array_res = array();
            $array_res["CA_TOTAL"] = 0;
            $array_res["CATEG"] = array();

            while ($objp = $db->fetch_object($resql)) {
                if ($objp->facid != $old_id){
                    $distint_ref ++;
                    $old_id = $objp->facid;
                    $invoicetmp->fetch($objp->facid);
                    $array_res["CA_TOTAL"] += $invoicetmp->total_ht;
                    foreach ($invoicetmp->lines as $val) {
                        $c = new Categorie($db);
                        $cats = $c->containing($val->fk_product, Categorie::TYPE_PRODUCT);
                        $array_res["CATEG"][$cats[0]->id]["NB"] += $val->qty;
                        $array_res["CATEG"][$cats[0]->id]["HT"] += $val->total_ht;
                        $array_res["CATEG"][$cats[0]->id]["TTC"] += $val->total_ttc;
                        $array_res["CATEG"][$cats[0]->id]["TVA"] += $val->total_tva;
                        $array_res["TVA_VENTILLATION"][$val->tva_tx]["HT"] += $val->total_ht;
                        $array_res["TVA_VENTILLATION"][$val->tva_tx]["TTC"] += $val->total_ttc;
                        $array_res["TVA_VENTILLATION"][$val->tva_tx]["TVA"] += $val->total_tva;
                        $array_res["PRODUCT_QTY"][$val->fk_product]["QTY"] += $val->qty;
                        $array_res["PRODUCT_QTY"][$val->fk_product]["TTC"] += $val->total_ttc;
                        $array_res["PRODUCT_QTY"][$val->fk_product]["TVA"] += $val->total_tva;
                        $array_res["PRODUCT_QTY"][$val->fk_product]["HT"] += $val->total_ht;
                    }
                }
                $array_res["PaymentMode"][$objp->code]["TTC"] += $objp->amount;
            }

            $array_res["NB_VENTE"] = $distint_ref;

            print "<div style='text-align: left'>";
            print '<br>' . $langs->trans("CA_TOTAL") . ': ' . price($array_res["CA_TOTAL"]);
            print '<br>' . $langs->trans("NB_VENTE") . ': ' . $array_res["NB_VENTE"];
            if ($num == 0) {
                $num = 1;
            }
            print '<br>' . $langs->trans("MOY_TICKET") . ': ' . price($array_res["CA_TOTAL"] / $num);
            print "</div>";
            print "<div style='text-align: left'><h2>";
            print $langs->trans("FAMILLE_DETAIL");
            print "</h2></div>";

            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";

            $param = '';

            // Fields title
            print '<tr class="liste_titre">';
            print_liste_field_titre($arrayfields['p.categ']['label'], $_SERVER['PHP_SELF'], 'p.categ', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($arrayfields['c.nbr']['label'], $_SERVER['PHP_SELF'], 'c.nbr', '', $param, '"', $sortfield, $sortorder);
            print_liste_field_titre($arrayfields['c.HT']['label'], $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($arrayfields['c.tva']['label'], $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($arrayfields['c.ttc']['label'], $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
            print "</tr>\n";

            // Loop on each record
            $cash = $bank = $cheque = $other = 0;
            $totalqty = 0;
            $totalvat = 0;
            $totalvatperrate = array();
            $totallocaltax1 = 0;
            $totallocaltax2 = 0;
            $cachebankaccount = array();
            $cacheinvoiceid = array();
            $transactionspertype = array();
            $amountpertype = array();
            $totalarray = array();
            foreach ($array_res["CATEG"] as $key => $val) {
                $categories = new Categorie($db);
                $categories->fetch($array_res["CATEG"]);
                $sql = "SELECT label FROM " . MAIN_DB_PREFIX . "categorie where rowid = " . $key;
                $resLabel = $db->query($sql);
                if (!empty($resLabel->num_rows)) {
                    $res = $db->fetch_object($resLabel);
                    print '<tr class="oddeven">';
                    // TAG/CATEG
                    print '<td class="nowrap left">';
                    print $res->label;
                    print '</td>';
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }

                    // NB Produits
                    print '<td class="nowrap left">';
                    print $val["NB"];
                    print "</td>\n";
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // HT
                    print '<td class="nowrap left">';
                    print price($val["HT"]);
                    print "</td>\n";
                    $totalarray['ht'] += $val["HT"];

                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // VAT
                    print '<td class="nowrap left">';
                    print price($val["TVA"]);
                    print "</td>\n";
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // TTC
                    print '<td class="nowrap left">';
                    print price($val["TTC"]);
                    print "</td>\n";
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    $totalarray['tot'] += $val["TTC"];
                    print "</tr>";
                }
            }


            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";
            print '<tr class="liste_total">';
            print '<td>' . $langs->trans("Total") . '</td>';
            print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
            print '<td class="right">' . price($totalarray['tot']) . ' TTC</td>';
            print '</tr>';
            print "</table>";
            print "</div>";

            print "<div style='text-align: left'><h2>";
            print $langs->trans("ENCAISSEMENT_DETAIL");
            print "</h2></div>";

            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";

            $param = '';

            // Fields title
            print '<tr class="liste_titre">';
            print_liste_field_titre($langs->trans("PaymentMode"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans(" "), $_SERVER['PHP_SELF'], '', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans(" "), $_SERVER['PHP_SELF'], '', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("SellingPrice_TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
            print "</tr>\n";

            // Loop on each record
            $cash = $bank = $cheque = $other = 0;
            $totalqty = 0;
            $totalvat = 0;
            $totalvatperrate = array();
            $totallocaltax1 = 0;
            $totallocaltax2 = 0;
            $cachebankaccount = array();
            $cacheinvoiceid = array();
            $transactionspertype = array();
            $amountpertype = array();
            $totalarray = array();
            foreach ((array)$array_res["PaymentMode"] as $key => $val) {
                $categories = new Categorie($db);
                $categories->fetch($array_res["CATEG"]);
                $sql = "SELECT libelle FROM " . MAIN_DB_PREFIX . "c_paiement where code = '" . $key . "'";
                $resLabel = $db->query($sql);
                if (!empty($resLabel->num_rows)) {
                    $res = $db->fetch_object($resLabel);
                    print '<tr class="oddeven">';
                    // TAG/CATEG
                    print '<td class="nowrap left">';
                    print $res->libelle;
                    print '</td>';
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // HT
                    print '<td class="nowrap left">';
//                    print price($val["HT"]);
                    print "</td>\n";
                    $totalarray['ht'] += $val["HT"];
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // VAT
                    print '<td class="nowrap left">';
//                    print price($val["TVA"]);
                    print "</td>\n";
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    // TTC
                    print '<td class="nowrap left">';
                    print price($val["TTC"]);
                    $totalarray["ttc"] += $val["TTC"];
                    print "</td>\n";
                    if (!$i) {
                        $totalarray['nbfield']++;
                    }
                    print "</tr>";
                }
            }


            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";
            print '<tr class="liste_total">';
            print '<td>' . $langs->trans("Total") . '</td>';
//            print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
            print '<td class="right">' . price($totalarray['ttc']) . ' TTC</td>';
            print '</tr>';
            print "</table>";
            print "</div>";


            print "<div style='text-align: left'><h2>";
            print $langs->trans("TVA_VENTILLATION");
            print "</h2></div>";

            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";

            $param = '';

            // Fields title
            print '<tr class="liste_titre">';
            print_liste_field_titre($langs->trans("TXTVA"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("HT"), $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("TVA"), $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("SellingPrice_TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
            print "</tr>\n";
            // Loop on each record
            $cash = $bank = $cheque = $other = 0;
            $totalqty = 0;
            $totalvat = 0;
            $totalvatperrate = array();
            $totallocaltax1 = 0;
            $totallocaltax2 = 0;
            $cachebankaccount = array();
            $cacheinvoiceid = array();
            $transactionspertype = array();
            $amountpertype = array();
            $totalarray = array();
            foreach ((array)$array_res["TVA_VENTILLATION"] as $key => $val) {
                print '<tr class="oddeven">';
                // TAG/CATEG
                print '<td class="nowrap left">';
                print round($key, 2) . " %";
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // HT
                print '<td class="nowrap left">';
                print price($val["HT"]);
                print "</td>\n";
                $totalarray['ht'] += $val["HT"];
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // VAT
                print '<td class="nowrap left">';
                print price($val["TVA"]);
                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // TTC
                print '<td class="nowrap left">';
                print price($val["TTC"]);
                $totalarray["ttc"] += $val["TTC"];
                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                print "</tr>";
            }

            print '<div class="div-table-responsive">';
            print '<table class="tagtable liste">' . "\n";
            print '<tr class="liste_total">';
            print '<td>' . $langs->trans("Total") . '</td>';
            print '<td class="left">' . price($totalarray['ht']) . ' HT</td>';
            print '<td class="right">' . price($totalarray['ttc']) . ' TTC</td>';
            print '</tr>';
            print "</table>";
            print "</div>";

            print "<div style='text-align: left'><h2>";
            print $langs->trans("TICKET_RECAPITULATIF_DES_VENTES_PAR_PRODUITS");
            print "</h2></div>";

            print '<div class="">';
            print '<table class="tagtable liste">' . "\n";

            $param = '';

            // Fields title
            print '<tr class="liste_titre">';
            print_liste_field_titre($langs->trans("PROD"), $_SERVER['PHP_SELF'], 'p.payement', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("PROD_QTY"), $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("HT"), $_SERVER['PHP_SELF'], 'c.HT', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("TVA"), $_SERVER['PHP_SELF'], 'c.tva', '', $param, '', $sortfield, $sortorder);
            print_liste_field_titre($langs->trans("TTC"), $_SERVER['PHP_SELF'], 'c.ttc', '', $param, '', $sortfield, $sortorder);
            print "</tr>\n";
            // Loop on each record
            $cash = $bank = $cheque = $other = 0;
            $totalqty = 0;
            $totalvat = 0;
            $totalvatperrate = array();
            $totallocaltax1 = 0;
            $totallocaltax2 = 0;
            $cachebankaccount = array();
            $cacheinvoiceid = array();
            $transactionspertype = array();
            $amountpertype = array();
            $totalarray = array();
            foreach ((array)$array_res["PRODUCT_QTY"] as $key => $val) {
                print '<tr class="oddeven">';
                // TAG/CATEG
                $object_product->fetch($key);
                print '<td class="nowrap left">';
                print $object_product->label;
                print '</td>';
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // HT
                print '<td class="nowrap left">';
                print $val["QTY"];
                print "</td>\n";
                $totalarray['qty'] += $val["QTY"];
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // HT
                print '<td class="nowrap left">';
                print price($val["HT"]);
                print "</td>\n";
                $totalarray['ht'] += $val["HT"];
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // VAT
                print '<td class="nowrap left">';
                print price($val["TVA"]);
                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                // TTC
                print '<td class="nowrap left">';
                print price($val["TTC"]);
                $totalarray["ttc"] += $val["TTC"];
                print "</td>\n";
                if (!$i) {
                    $totalarray['nbfield']++;
                }
                print "</tr>";
            }

            print '<div class="div-table-responsive">';
            print '<table class="tagtable liste">' . "\n";
            print '<tr class="liste_total">';
            print '<td>' . $langs->trans("Total") . '</td>';

            print '<td colspan="2">' . $totalarray['qty'] . ' ' . $langs->trans("Products") . '</td>';
            print '<td colspan="2"></td>';
            print '<td colspan="2">' . price($totalarray['ht']) . ' HT</td>';
            print '<td colspan="2"></td>';
            print '<td colspan="2">' . price($totalarray['ttc']) . ' TTC</td>';
            print '</tr>';
            print "</table>";
            print "</div>";


            print '</form>';

            $db->free($resql);
        } else {
            dol_print_error($db);
        }
    }
}

// End of page
llxFooter();
$db->close();
